==> wasabiD-0.2.92.tgz: package/Base/Form/CheckBox.jsx <==
/**
 * Created by zhiyongwang on 2016-04-01.
 * 单选组件
 */
require("../../sass/Base/Form/Check.scss");
let React=require("react");
let alogUtil=require("../../libs/alogUtil.js");

let CheckBox=React.createClass({
    PropTypes:{
        name: React.PropTypes.string.isRequired,//对应表单name属性，用于提交
        label:React.PropTypes.string,//描述文字
        placeholder:React.PropTypes.string,//输入框内的提示文字
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        value:React.PropTypes.string,//默认value值，
        text:React.PropTypes.string,//默认text值
        className:React.PropTypes.string,//附加新式
        readonly:React.PropTypes.bool,//是否只读,
        hide:React.PropTypes.hide,//是否隐藏 :
        url:React.PropTypes.string,//ajax的后台地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.string,//数据源
        onSelect: React.PropTypes.func,//选中后的事件，回传，value,与text

    },
    getDefaultProps:function() {
        return{
            label:"",
            placeholder:"",
            valueField:"value",
            textField:"text",
            value:"",
            text:"",
            url:null,
            backSource:null,
            readonly:false,
            className:"",
            hide:false,
            data:[],
            onSelect:null
        };
    },
    getInitialState:function() {
        return {
            data:(this.props.data),
            value:this.props.value,
            text:this.props.text,
            readonly:this.props.readonly,
        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
            value: nextProps.value,
            text: nextProps.text,
            readonly:nextProps.readonly,
            data:(nextProps.data)
        });
    },
    componentWillMount:function() {//如果指定url,先查询数据再绑定
        if(this.props.url!=null)
        {
            var fetchmodel=new FetchModel(this.props.url,this.loadSuccess);
            alogUtil.fetch.get(fetchmodel);
        }


    },
    loadSuccess:function(data) {//数据加载成功
        if(this.props.backSource==null)
        {
            this.setState({
                data:data
            });
        }else {
            this.setState({
                data:data[this.props.backSource]
            });
        }

    },
    changeHandler:function(event) {//一害绑定，但不处理
        if(this.state.readonly) {
            event.preventDefault();
        }
    },
    onSelect:function(value,text,event) {//选中事件
        if(this.state.readonly)
        {
            return ;
        }
        var newvalue="";var newtext="";
        if(!this.state.value||this.state.value=="")
        {//肯定是选中
            newvalue=value;
            newtext=text;
        }
        else
        {
            var oldvalue=","+this.state.value.toString();//加逗号是为了防止判断失误，国为某些可能正好包含在另外一个值中
            var oldtext=","+this.state.text.toString();
            if(oldvalue.indexOf("," +value)>-1) {
                //取消选中
                newvalue=oldvalue.replace("," + value.toString(), "");
                newtext=oldtext.replace("," + text, "");

            }
            else {
                newvalue=this.state.value+","+value;
                newtext=this.state.text+","+text;
            }
        }
            this.setState({
                value:newvalue,
                text:newtext
            });
        if(this.props.onChange) {
            this.props.onChange(newvalue,newtext);
        }

        if( this.props.onSelect!=null)
        {
          this.props.onSelect(newvalue,newtext,this.props.name);
        }
    },
    render:function() {
        var control;
        if(this.state.data) {
            control= this.state.data.map((child, i)=> {
                var checked=false;
                if(this.state.value&&((","+this.state.value.toString()).indexOf(","+child[this.props.valueField])>-1))
                {
                    checked=true;
                }
                var props={
                    checked:(checked==true?"checked":null),//是否为选中状态
                    readOnly:this.state.readonly==true?"readonly":null,
                }
             return    <li key={i} >
                <input type="checkbox"  id={"checkbox"+this.props.name+child[this.props.valueField]}  value={child[this.props.valueField]}
                                   onClick={this.onSelect.bind(this,child[this.props.valueField],child[this.props.textField])}
                                   onChange={this.changeHandler} className="checkbox"  {...props}></input>
                    <label htmlFor={"checkbox"+this.props.name+child[this.props.valueField]}  {...props}></label>
                 <div  className="checktext">{child[this.props.textField]} </div>
                    </li >
            });

        }
        return (
            <ul className="checkul">
                {
                    control
                }
            </ul>
        )

    }

});
module.exports=CheckBox;

==> wasabiD-0.2.983.tgz: package/Base/Form/CheckBox.jsx <==
/**
 * Created by zhiyongwang on 2016-04-01.
 * 单选组件
 */
require("../../sass/Base/Form/Check.scss");
let React=require("react");
let unit=require("../../libs/unit.js");

let CheckBox=React.createClass({
    PropTypes:{
        name: React.PropTypes.string.isRequired,//对应表单name属性，用于提交
        label:React.PropTypes.string,//描述文字
        placeholder:React.PropTypes.string,//输入框内的提示文字
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        value:React.PropTypes.string,//默认value值，
        text:React.PropTypes.string,//默认text值
        className:React.PropTypes.string,//附加新式
        readonly:React.PropTypes.bool,//是否只读,
        hide:React.PropTypes.hide,//是否隐藏 :
        url:React.PropTypes.string,//ajax的后台地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.string,//数据源
        onSelect: React.PropTypes.func,//选中后的事件，回传，value,与text

    },
    getDefaultProps:function() {
        return{
            label:"",
            placeholder:"",
            valueField:"value",
            textField:"text",
            value:"",
            text:"",
            url:null,
            backSource:null,
            readonly:false,
            className:"",
            hide:false,
            data:[],
            onSelect:null
        };
    },
    getInitialState:function() {
        return {
            data:(this.props.data),
            value:this.props.value,
            text:this.props.text,
            readonly:this.props.readonly,
        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
            value: nextProps.value,
            text: nextProps.text,
            readonly:nextProps.readonly,
            data:(nextProps.data)
        });
    },
    componentWillMount:function() {//如果指定url,先查询数据再绑定
        if(this.props.url!=null)
        {
            var fetchmodel=new FetchModel(this.props.url,this.loadSuccess);
            unit.fetch.get(fetchmodel);
        }


    },
    loadSuccess:function(data) {//数据加载成功
        if(this.props.backSource==null)
        {
            this.setState({
                data:data
            });
        }else {
            this.setState({
                data:data[this.props.backSource]
            });
        }

    },
    changeHandler:function(event) {//一害绑定，但不处理
        if(this.state.readonly) {
            event.preventDefault();
        }
    },
    onSelect:function(value,text,event) {//选中事件
        if(this.state.readonly)
        {
            return ;
        }
        var newvalue="";var newtext="";
        if(!this.state.value||this.state.value=="")
        {//肯定是选中
            newvalue=value;
            newtext=text;
        }
        else
        {
            var oldvalue=","+this.state.value.toString();//加逗号是为了防止判断失误，国为某些可能正好包含在另外一个值中
            var oldtext=","+this.state.text.toString();
            if(oldvalue.indexOf("," +value)>-1) {
                //取消选中
                newvalue=oldvalue.replace("," + value.toString(), "");
                newtext=oldtext.replace("," + text, "");

            }
            else {
                newvalue=this.state.value+","+value;
                newtext=this.state.text+","+text;
            }
        }
            this.setState({
                value:newvalue,
                text:newtext
            });
        if(this.props.onChange) {
            this.props.onChange(newvalue,newtext);
        }

        if( this.props.onSelect!=null)
        {
          this.props.onSelect(newvalue,newtext,this.props.name);
        }
    },
    render:function() {
        var control;
        if(this.state.data) {
            control= this.state.data.map((child, i)=> {
                var checked=false;
                if(this.state.value&&((","+this.state.value.toString()).indexOf(","+child[this.props.valueField])>-1))
                {
                    checked=true;
                }
                var props={
                    checked:(checked==true?"checked":null),//是否为选中状态
                    readOnly:this.state.readonly==true?"readonly":null,
                }
             return    <li key={i} >
                <input type="checkbox"  id={"checkbox"+this.props.name+child[this.props.valueField]}  value={child[this.props.valueField]}
                                   onClick={this.onSelect.bind(this,child[this.props.valueField],child[this.props.textField])}
                                   onChange={this.changeHandler} className="checkbox"  {...props}></input>
                    <label htmlFor={"checkbox"+this.props.name+child[this.props.valueField]}  {...props}></label>
                 <div  className="checktext">{child[this.props.textField]} </div>
                    </li >
            });

        }
        return (
            <ul className="checkul">
                {
                    control
                }
            </ul>
        )

    }

});
module.exports=CheckBox;
